# Drone imagery and metabarcoding in field diagnostics

This repository contains the supplementary code and intermediary data for the metabarcoding data analysis performed as part of the study 
'Drone imagery and metabarcoding as diagnostic tools of poor growth in potato fields' by Persdatter et al.

## Content

The repository includes the following contents:

1. **'analysis' folder**: contains scripts and intermediary files used and generated in the analysis.
Analysis was largely conducted per primer used in metabarcoding and then synthesized in some higher level analyses.
For each primer pair (marker), the following is provided
   - R script for the metabarcoding data analysis, including data preprocessing, diversity analysis, and statistical testing.
   - Intermediary metabarcoding data, including amplicon sequence variants (ASVs), taxonomy, ASV counts for each sample and DADA2 processing logs.
   - Metadata for the samples, including NDVI, and other relevant variables.

2. **'manuscript files' folder**: contains the larger tables presented in the manuscript

3. **'SRA submission' folder**: contains metadata used for submission of reads to NCBI's Short Read Archive

4. **README.md**: This file, providing an overview of the repository and instructions for use.

## Usage

1. Clone the repository to your local machine:

   ```
   git clone https://gitlab.nibio.no/simeon/persdatter-et-al-2025-metabarcoding.git
   ```

2. Optional: Obtain the raw read data from [SRA](https://www.ncbi.nlm.nih.gov/bioproject/) under the BioProject with the accession PRJNA1191665. 
Run the DADA2 scripts in `/analysis/raw_read_processing`. This will re-generate the intermediate data from raw reads. The intermediate data is 
already contained in each of the marker directories, e.g. `/analysis/16S/16S_DADA2_results_260821`.

3. Ensure you have the necessary R packages installed. All necessary dependencies required by the analysis scripts are listed in the top chunks of the respective scripts.

4. Open the R Markdown file contained in each of the marker directories, e.g. `/analysis/16S/16S_DADA2_results_260821` to reproduce the metabarcoding data analysis.

## Citing this Repository

If you use the code or data from this repository in your own work, please cite the original publication:

```
To be updated upon publication
```

Before publication, please acknowledge the use of this supplementary repository by citing it as follows:

```
MP Tangvik et al. (2024). Supplementary code and data for 'Drone imagery and metabarcoding as diagnostic tools of poor growth in potato fields' [Data set]. GitLab. https://gitlab.nibio.no/simeon/persdatter-et-al-2025-metabarcoding
```

## Contact

For any questions or issues related to this repository, please contact [Simeon Lim Rossmann](mailto:simeon.rossmann@nibio.no) or [Marte Persdatter Tangvik](mailto:marte.tangvik@nibio.no)
